@@ -2,14 +2,8 @@
 
 import ctypes as c
 import os
-import sys
-
-if sys.platform.startswith('darwin'):
-    _ = c.CDLL(os.path.join(os.path.dirname(__file__), "gmp.dylib"))
-
-if sys.platform.startswith('cygwin') or sys.platform.startswith('win32'):
-    _ = c.CDLL(os.path.join(os.path.dirname(__file__), "gmp.dll"))
 
+_ = c.CDLL(os.path.join(os.path.dirname(__file__), "gmp.dylib"))
 
 _.pfib.argtypes = (c.c_ulonglong,)
 
